import os

from sqlalchemy.ext.asyncio import AsyncSession
from sqlalchemy.ext.asyncio import create_async_engine
from sqlalchemy.orm import sessionmaker

database_url = (
    f'postgresql+asyncpg://{os.environ.get("POSTGRES_USER")}:'
    + f'{os.environ.get("POSTGRES_PASSWORD")}@'
    + os.environ.get("POSTGRES_CONTAINER")
    + f':5432/{os.environ.get("POSTGRES_DB")}'
)

engine = create_async_engine(database_url, echo=True, future=True)


async def get_session() -> AsyncSession:
    async_session = sessionmaker(engine, class_=AsyncSession, expire_on_commit=False)
    async with async_session() as session:
        yield session
